pub struct MidPoint { /* private fields */ }Expand description
Midpoint (MIDPOINT): the average of the highest and lowest value of the
input series over the last period points.
MIDPOINT = (highest(value, period) + lowest(value, period)) / 2Where MidPrice takes the window extremes from a candle’s
high/low, MIDPOINT works on a single scalar stream (typically the close),
taking the max and min of that stream over the window. The first value is
emitted once period points have been seen.
Example
use wickra_core::{Indicator, MidPoint};
let mut indicator = MidPoint::new(5).unwrap();
let mut last = None;
for i in 0..40 {
last = indicator.update(100.0 + f64::from(i));
}
assert!(last.is_some());Implementations