ZigZagOutput

Struct ZigZagOutput 

pub struct ZigZagOutput {
    pub swing: f64,
    pub direction: f64,
}
ZigZag output: the price of the bar that completed the most recent swing and its direction (+1.0 for a high swing, -1.0 for a low swing).

The price is the high of the bar at which the high-swing was anchored, or the low of the bar at which the low-swing was anchored — i.e. the actual extreme that the swing turns from, not the bar that triggered confirmation.

Fields

swing: f64

Price of the confirmed swing extreme.

direction: f64

Direction: +1.0 if the swing is a high, -1.0 if a low.