pub struct Level {
pub price: f64,
pub size: f64,
}Expand description
A single order-book price level: a resting quantity at a price.
Fields
price: f64Price of the level (strictly positive).
size: f64Resting size / quantity at this price (non-negative).
Implementations
Sourceimpl Level
impl Level
Sourcepub fn new(price: f64, size: f64) -> Result<Self>
pub fn new(price: f64, size: f64) -> Result<Self>
Construct a level, validating that price is finite and strictly
positive and size is finite and non-negative.
Errors
Returns Error::InvalidOrderBook if the price is not a finite
positive number, or the size is not a finite non-negative number.
Sourcepub const fn new_unchecked(price: f64, size: f64) -> Self
pub const fn new_unchecked(price: f64, size: f64) -> Self
Construct a level without validation. The caller asserts that price
is finite and positive and size is finite and non-negative.